@@ -3,12 +3,13 @@ use crate::lang::LangDetectors;
 use std::cell::RefCell;
 use std::collections::{BTreeMap, HashSet};
 use std::path::{Path};
-use crate::frameworks::Frameworks;
+use crate::frameworks::{Frameworks, Framework};
 
 #[derive(Serialize, Deserialize, PartialEq, Debug, Clone)]
-pub struct Framework {
+pub struct DetectFramework {
     pub name: String,
     pub path: String,
+    pub relative: String,
     // in some languages has different framework file
     // |   languages |   files    |
     // |-------------|------------|
@@ -26,7 +27,7 @@ pub struct SourceFile {
 
 #[derive(Serialize)]
 pub struct FrameworkContainer {
-    entries: RefCell<Vec<Framework>>,
+    entries: RefCell<Vec<DetectFramework>>,
 
     #[serde(skip_serializing)]
     temp_source_files: RefCell<Vec<SourceFile>>,
@@ -34,14 +35,14 @@ pub struct FrameworkContainer {
 
 impl FrameworkContainer {
     /// add framework to project
-    pub fn add_framework(&self, framework: Framework) {
+    pub fn add_framework(&self, framework: DetectFramework) {
         if !self.entries.borrow().contains(&framework) {
             self.associate_with_source_files(&framework);
             self.entries.borrow_mut().push(framework);
         }
     }
 
-    fn associate_with_source_files(&self, framework: &Framework) {
+    fn associate_with_source_files(&self, framework: &DetectFramework) {
         for temp_source_file in self.temp_source_files.borrow().iter() {
             if temp_source_file.file_path.starts_with(&framework.path) {
                 FrameworkContainer::add_language_to_framework(temp_source_file.language.clone(), framework)
@@ -62,7 +63,7 @@ impl FrameworkContainer {
         }
     }
 
-    fn add_language_to_framework(language: String, framework: &Framework) {
+    fn add_language_to_framework(language: String, framework: &DetectFramework) {
         framework.languages.borrow_mut().insert(language);
     }
 
@@ -87,7 +88,7 @@ impl FrameworkContainer {
         }
     }
 
-    pub fn get(&self, index: usize) -> Option<Framework> {
+    pub fn get(&self, index: usize) -> Option<DetectFramework> {
         let frameworks = self.entries.borrow();
         match frameworks.get(index) {
             Some(framework) => Some(framework.clone()),
@@ -108,7 +109,7 @@ impl Default for FrameworkContainer {
 /// Framework Detector
 #[derive(Serialize)]
 pub struct FrameworkDetector<'a> {
-    tags: BTreeMap<&'a str, bool>,
+    pub(crate) tags: BTreeMap<&'a str, bool>,
 
     pub container: FrameworkContainer,
     pub facets: Vec<Box<Facet>>,
@@ -141,9 +142,18 @@ impl<'a> FrameworkDetector<'a> {
     }
 
     pub fn build(&self) -> Frameworks {
+        let frameworks = self.container.entries.borrow()
+            .to_vec()
+            .iter()
+            .map(|fw| Framework::from(fw))
+            .collect();
+        let facets = self.facets.iter()
+            .map(|s| serde_json::to_value(s).unwrap())
+            .collect();
+
         Frameworks {
-            frameworks: self.container.entries.borrow().to_vec(),
-            facet: self.facets.iter().map(|s| serde_json::to_value(s).unwrap()).collect()
+            frameworks,
+            facets
         }
     }
 
